Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func CombinedLogger ¶
CombinedLogger and CommonLogger are middlewares that log to stderr all http requests and response in Apache CommonLog and CombinedLog formats. They also log the answer delay in ms.
These loggers are directly ported from gorilla handlers https://github.com/gorilla/handlers
CombinedLogger returns a middleware that logs HTTP requests to `out` Writer in combined log format
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.